@@ -191,8 +191,15 @@ static gint document_replace_real(GtkWidget *textview)
 				if (num == 0 && q_dialog == NULL)
 					q_dialog = create_dialog_message_question(
 						gtk_widget_get_toplevel(textview), _("Replace?"));
+#if GTK_CHECK_VERSION(2, 10, 0)
+					GtkTextIter ins,bou;
+					gtk_text_buffer_get_selection_bounds(textbuffer, &ins, &bou);
+#endif
 				switch (gtk_dialog_run(GTK_DIALOG(q_dialog))) {
 				case GTK_RESPONSE_YES:
+#if GTK_CHECK_VERSION(2, 10, 0)
+					gtk_text_buffer_select_range(textbuffer, &ins, &bou);
+#endif
 					break;
 				case GTK_RESPONSE_NO:
 					continue;
